@@ -1,33 +1,34 @@
 
 class Authenticate:
-    def __init__(self, session, asset, asset_manifest):
+    def __init__(self, session, asset, security):
         self.session = session
-        self.asset_manifest = asset_manifest
+        self.security = security
         self.asset = asset
+        self.params = {}
 
         self.authentication_handler()
 
     def authentication_handler(self):
-        security = self.asset_manifest['meta']['security']
         auth_map = {
             'apiKey': self.apikey_auth,
         }
 
-        auth_map[security['type']]()
+        auth_map[self.security['type']]()
 
         return self.session
 
     def apikey_auth(self):
-        security = self.asset_manifest['meta']['security']
         switcher = {
             'header': self.session.headers.update({
-                security['name']: self.asset[security['name']]
+                self.security['name']: self.asset[self.security['name']]
             }),
             'cookie': NotImplementedError,
-            'query': NotImplementedError,
+            'query': self.params.update({
+                self.security['name']: self.asset[self.security['name']]
+            }),
         }
 
-        switch = switcher[security['in']]
+        switch = switcher[self.security['in']]
 
         # todo: remove this once all switches are implemented
         if callable(switch):
